@@ -42,6 +42,15 @@ wording = {
     'wikipedia':'Wikipedia',
     }     
 
+
+about_txt = """
+Ask Ziggy - Search for news, weather, translations, reviews,\t\t
+ movies, wikipedia entries and more...\n
+<small>&#169; 2010 Martin Borho &lt;martin@borho.net&gt;\t\t\t\n
+License: GNU General Public License (GPL) Version 3
+Source: <span color="orange">http://github.com/mborho/ask-ziggy</span></small>
+"""
+
 class AppState(object):
 
         def __init__(self):
@@ -59,8 +68,8 @@ class BaasGui(object):
         gtk.set_application_name("Ask Ziggy")
         
         # Create a new programm
-        program = hildon.Program.get_instance()
-
+        program = hildon.Program.get_instance()        
+        
         # Create a new window
         self.window = hildon.StackableWindow()
         self.window.set_default_size(400,200)
@@ -68,6 +77,9 @@ class BaasGui(object):
         self.window.connect("delete_event", self.delete_event)
         self.window.set_border_width(10)
         
+        menu = self.create_menu()
+        self.window.set_app_menu(menu)        
+        
         self.box = gtk.HBox(False, 5)
         self.window.add(self.box)
         
@@ -92,6 +104,26 @@ class BaasGui(object):
         self.box.show()
         self.window.show()             
         
+    def create_menu(self):
+        menu = hildon.AppMenu()
+        about = hildon.GtkButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_THUMB_HEIGHT)
+        about.set_label('About')
+        about.connect('clicked', self.menu_dialog,about_txt)
+        
+        menu.append(about)
+        menu.show_all()
+        return menu
+        
+    def menu_dialog(self, button, text):
+        
+        label = gtk.Label() 
+        label.set_markup(text)
+        dialog = gtk.Dialog()
+        dialog.set_title(button.get_label())
+        dialog.set_transient_for(self.window)
+        dialog.action_area.pack_start(label, True, True, 0)
+        dialog.show_all()
+                    
     def show_service_window(self, widget, service_name):
 
         self.input_command = service_name
@@ -101,33 +133,37 @@ class BaasGui(object):
         self.service_win = hildon.StackableWindow()
         self.service_win.set_title(wording.get(service_name))            
 
-        # text input
-        textentry = hildon.TextView()
-
         # fill text entry with last search
         last_input = self.state.buffers.get(self.input_command,'')
-        self.input_buffer = last_input
-        old_buffer = gtk.TextBuffer()
-        old_buffer.set_text(last_input)
-        textentry.set_buffer(old_buffer)
 
-        buffer = textentry.get_buffer()
-        buffer.connect("changed", self.input_changed)  
+        # single entry line
+        self.entry = hildon.Entry(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_THUMB_HEIGHT)
+        self.entry.set_text(last_input)
 
         # go button
-        button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_AUTO_HEIGHT, 
+        button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_THUMB_HEIGHT, 
             hildon.BUTTON_ARRANGEMENT_HORIZONTAL, "go")
         button.connect("clicked", self.ask_buddy)
         button.connect("pressed", self.waiting_start)
         
         if self.input_command == "deli":
-            input_box = self.input_deli(textentry, button)
+            input_box = self.input_deli(self.entry, button)
         elif self.input_command == "metacritic":
-            input_box = self.input_metacritic(textentry, button)
+            input_box = self.input_metacritic(self.entry, button)
         elif self.input_command == "tlate":
-            input_box = self.input_translate(textentry, button)        
+            # text input
+            self.textentry = hildon.TextView()        
+            self.input_buffer = last_input
+            old_buffer = gtk.TextBuffer()
+            old_buffer.set_text(last_input)
+            self.textentry.set_buffer(old_buffer)
+
+            buffer = self.textentry.get_buffer()
+            buffer.connect("changed", self.input_changed)  
+
+            input_box = self.input_translate(self.textentry, button)        
         else:
-            input_box = self.input_websearch(textentry, button)
+            input_box = self.input_websearch(self.entry, button)
 
         # the results
         self.result_area = gtk.VBox(False, 5)                      
@@ -140,7 +176,7 @@ class BaasGui(object):
 
     def get_lang_button(self):
         """ builds button for language selection """
-        lang_button = hildon.PickerButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_AUTO_HEIGHT, 
+        lang_button = hildon.PickerButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_THUMB_HEIGHT, 
             hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
 
         selector = hildon.TouchSelector()
@@ -189,7 +225,7 @@ class BaasGui(object):
 
     def get_edition_button(self):
         """ builds button for google news language selection """
-        lang_button = hildon.PickerButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_AUTO_HEIGHT, 
+        lang_button = hildon.PickerButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_THUMB_HEIGHT, 
             hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
         lang_button.set_label("edition")
         selector = hildon.TouchSelector(text=True)        
@@ -223,28 +259,42 @@ class BaasGui(object):
         if self.input_command == "gnews":lang_button = self.get_edition_button()
         else: lang_button = self.get_lang_button()
 
-        lang_button.set_size_request(210, 50)
-        textentry.set_size_request(350, 50)         
-        button.set_size_request(120, 50)     
-        button.set_border_width(2)
-        lang_button.set_border_width(2)
+        lang_button.set_size_request(210, 40)
+        textentry.set_size_request(350, 70)  
+        button.set_size_request(130, 40)     
+        button.set_border_width(1)
+        lang_button.set_border_width(1)
+        
+        box2 = gtk.HBox(False)
+        box2.pack_start(lang_button, True, True, 0)
+        box2.pack_start(button, False, True, 0)
+        box2.set_size_request(250, 50)
 
+        table = gtk.Table(1, 20, False)
+        table.attach(textentry, 0, 12, 0 , 1, xpadding=3)
+        table.attach(box2, 13, 20, 0 , 1, ypadding=10)
+        
         box = gtk.HBox(False)
-        box.pack_start(textentry, True, True, 0)
-        box.pack_start(lang_button, False, True, 0)
-        box.pack_start(button, False, True, 0)
+        box.pack_start(table, True, True, 0)
         return box
 
     def input_metacritic(self, textentry, button):
         ''' build input fields for metacritics '''
+        
+        textentry.set_size_request(350, 70)  
+        button.set_size_request(180, 70)     
+        button.set_border_width(1)
+              
+        box2 = gtk.HBox(False)
+        box2.pack_start(button, True, True, 0)
+        box2.set_size_request(280, 50)
 
-        textentry.set_size_request(350, 50)         
-        button.set_size_request(200, 50)     
-        button.set_border_width(2)
-
+        table = gtk.Table(1, 20, False)
+        table.attach(textentry, 0, 18, 0 , 1, xpadding=3)
+        table.attach(box2, 19, 20, 0 , 1, ypadding=12)
+        
         box = gtk.HBox(False)
-        box.pack_start(textentry, True, True, 0)
-        box.pack_start(button, False, True, 0)
+        box.pack_start(table, True, True, 0)
         return box
 
     def input_deli_pop(self, button):
@@ -253,23 +303,28 @@ class BaasGui(object):
 
     def input_deli(self, textentry, button):
         ''' build input fields for delicious service '''
-        pop_button = hildon.CheckButton(gtk.HILDON_SIZE_AUTO)
+        pop_button = hildon.CheckButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_THUMB_HEIGHT)
         pop_button.set_label("most popular")
         pop_button.connect("toggled", self.input_deli_pop)  
         pop_button.set_active(self.state.deli_pop)
 
-        button.set_border_width(2)
-        pop_button.set_border_width(2)
-
-        textentry.set_size_request(350, 50)
-        pop_button.set_size_request(220, 50)
-        button.set_size_request(150, 50)
-
-        box = gtk.HBox(False)
-        box.pack_start(textentry, True, True, 0)
-        box.pack_start(pop_button, False, True, 0)
-        box.pack_start(button, False, True, 0)
+        textentry.set_size_request(350, 70)  
+        pop_button.set_size_request(200, 50)
+        button.set_size_request(130, 50)     
+        button.set_border_width(1)
+        pop_button.set_border_width(1)
         
+        box2 = gtk.HBox(False)
+        box2.pack_start(pop_button, True, True, 0)
+        box2.pack_start(button, False, True, 0)
+        box2.set_size_request(250, 50)
+
+        table = gtk.Table(1, 20, False)
+        table.attach(textentry, 0, 10, 0 , 1,xpadding=3)
+        table.attach(box2, 11, 20, 0 , 1,ypadding=12)
+        
+        box = gtk.HBox(False)
+        box.pack_start(table, True, True, 0)
         return box
 
     def tlate_selected(self, selector, token):
@@ -283,7 +338,7 @@ class BaasGui(object):
 
     def get_tlate_button(self, label, token):
         """ builds button for language selection """
-        lang_button = hildon.PickerButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_AUTO_HEIGHT, 
+        lang_button = hildon.PickerButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_THUMB_HEIGHT, 
             hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
 
         selector = hildon.TouchSelector()
@@ -342,7 +397,6 @@ class BaasGui(object):
        text = buffer.get_text(start, end, False)
 
        self.input_buffer = text      
-       self.state.buffers[self.input_command] = self.input_buffer
 
     def prepare_term(self):
         ''' prepares statement for ape request '''
@@ -358,7 +412,6 @@ class BaasGui(object):
         else:
             term = self.input_buffer
         print "term %s" % term
-        print self.state.langs
         return term
 
 
@@ -372,11 +425,16 @@ class BaasGui(object):
 
         self.result_data = None
         commando_func = pluginHnd.commands.get(self.input_command)
+
+        if self.input_command != 'tlate':
+            self.input_buffer = self.entry.get_text()
         
         if self.input_buffer == '':
             self.waiting_stop()          
             return None            
 
+        self.state.buffers[self.input_command] = self.input_buffer
+
         if commando_func:                        
             term = self.prepare_term()              
             result_msg = ''
@@ -398,7 +456,7 @@ class BaasGui(object):
         
         if hasattr(self, 'result_output'):   
             self.result_output.destroy()
-        if self.input_command not in ['tlate','help','weather']:
+        if self.input_command not in ['tlate','weather']:
             self.result_output = self.create_result_selector(self.result_data)       
         else:            
             result_markup = self.get_result_markup()            
@@ -416,7 +474,6 @@ class BaasGui(object):
 
         if self.input_command == 'tlate':
             text = htmlentities_decode(data.get('text'))
-            print data
             lang = self.tlate_get_name(data.get('lang'))
             from_lang = self.tlate_get_name(data.get('detected_lang'))
             markup = "<big>%s</big>\n\n<small>(%s => %s)</small>" % (text, from_lang, lang)
@@ -439,7 +496,7 @@ class BaasGui(object):
 
     def create_result_text(self, result_markup):
         """ display result text """
-        self.result_output = hildon.PannableArea()
+        self.result_output = hildon.PannableArea()        
         if hasattr(self, 'result_text'):   
             self.result_text.destroy()
         self.result_text = gtk.Label()
